Module node

Module node 

DOM node types: Node, NodeData, ElementData, Attribute, TextNodeData.

Nodes are stored in BaseDocument’s arena and referenced by usize IDs. ElementData holds tag names, attributes, computed styles, layout state, and inline text data.

Structs

Attribute
A tag attribute, e.g. class="test" in <div class="test" ...>.
Attributes
BackgroundImageData
CanvasData
ElementData
ListItemLayout
Node
NodeFlags
RasterImageData
TextBrush
Parley Brush type for Bliss which contains the Bliss node id
TextInputData
TextLayout
TextNodeData

Enums

DisplayOuter
ImageData
ListItemLayoutPosition
Marker
NodeData
The different kinds of nodes in the DOM.
NodeKind
SpecialElementData
Heterogeneous data that depends on the element’s type.
SpecialElementType
Status